@@ -208,7 +208,7 @@ class Traceback(object):
             if self.is_syntax_error:
                 title = text_('Syntax Error')
             else:
-                title = text_('Traceback <em>(most recent call last)</em>:')
+                title = text_('Traceback <small>(most recent call last)</small>')
 
         for frame in self.frames:
             frames.append(
@@ -225,7 +225,7 @@ class Traceback(object):
 
         vars = {
             'classes':      text_(' '.join(classes)),
-            'title':        title and text_('<h3>%s</h3>' % title) or text_(''),
+            'title':        title and text_('<h3 class="traceback">%s</h3>' % title) or text_(''),
             'frames':       text_('\n'.join(frames)),
             'description':  description_wrapper % escape(self.exception),
         }
@@ -239,7 +239,8 @@ class Traceback(object):
         root_path = request.route_url(ROOT_ROUTE_NAME)
         exc = escape(self.exception)
         summary = self.render_summary(include_title=False, request=request)
-        qs = {'token': request.exc_history.token, 'tb': str(self.id)}
+        token = request.registry.parent_registry.pdtb_token
+        qs = {'token': token, 'tb': str(self.id)}
         url = request.route_url(EXC_ROUTE_NAME, _query=qs)
         evalex = request.exc_history.eval_exc
         vars = {
@@ -254,7 +255,7 @@ class Traceback(object):
             'plaintext_cs':     re.sub('-{2,}', '-', self.plaintext),
             'traceback_id':     self.id,
             'static_path':      static_path,
-            'token':            request.exc_history.token,
+            'token':            token,
             'root_path':        root_path,
             'url':              url,
         }
